@@ -15,7 +15,7 @@ build_time_vars = {'ABIFLAGS': 'm',
               '-Wl,-O1,--sort-common,--as-needed,-z,relro',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'armv7l-unknown-linux-gnueabi',
+ 'BUILD_GNU_TYPE': 'armv5tel-unknown-linux-gnueabi',
  'BYTESTR_DEPS': '\\',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
@@ -48,8 +48,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.6m',
  'COREPYTHONPATH': ':',
- 'COVERAGE_INFO': '/build/python/src/Python-3.6.4/coverage.info',
- 'COVERAGE_REPORT': '/build/python/src/Python-3.6.4/lcov-report',
+ 'COVERAGE_INFO': '/build/python/src/Python-3.6.5/coverage.info',
+ 'COVERAGE_REPORT': '/build/python/src/Python-3.6.5/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -D_FORTIFY_SOURCE=2 -D_FORTIFY_SOURCE=2',
@@ -123,6 +123,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_CONFSTR': 1,
  'HAVE_CONIO_H': 0,
  'HAVE_COPYSIGN': 1,
+ 'HAVE_CRYPT_H': 1,
  'HAVE_CTERMID': 1,
  'HAVE_CTERMID_R': 0,
  'HAVE_CURSES_FILTER': 1,
@@ -478,7 +479,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_WRITEV': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HOST_GNU_TYPE': 'armv7l-unknown-linux-gnueabi',
+ 'HOST_GNU_TYPE': 'armv5tel-unknown-linux-gnueabi',
  'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.6m '
                    '/usr/include/python3.6m',
  'INCLUDEDIR': '/usr/include',
@@ -618,7 +619,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.6.4',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.6.5',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '',
@@ -659,9 +660,9 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.6.4 ./python',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.6.5 ./python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.6.4 ./python '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.6.5 ./python '
                './Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'THREADOBJ': 'Python/thread.o',
@@ -686,8 +687,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python/src/Python-3.6.4',
- 'abs_srcdir': '/build/python/src/Python-3.6.4',
+ 'abs_builddir': '/build/python/src/Python-3.6.5',
+ 'abs_srcdir': '/build/python/src/Python-3.6.5',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
